@@ -3,11 +3,11 @@ mod call_hook;
 mod cli_tests;
 mod custom_signal_handler;
 mod debug;
+mod epoch_interruption;
 mod externals;
 mod fuel;
 mod func;
 mod funcref;
-mod fuzzing;
 mod gc;
 mod globals;
 mod host_funcs;
