@@ -3,7 +3,7 @@ use wasmtime::*;
 #[test]
 fn get_none() {
     let mut store = Store::<()>::default();
-    let ty = TableType::new(ValType::FuncRef, Limits::new(1, None));
+    let ty = TableType::new(ValType::FuncRef, 1, None);
     let table = Table::new(&mut store, ty, Val::FuncRef(None)).unwrap();
     match table.get(&mut store, 0) {
         Some(Val::FuncRef(None)) => {}
@@ -15,7 +15,7 @@ fn get_none() {
 #[test]
 fn fill_wrong() {
     let mut store = Store::<()>::default();
-    let ty = TableType::new(ValType::FuncRef, Limits::new(1, None));
+    let ty = TableType::new(ValType::FuncRef, 1, None);
     let table = Table::new(&mut store, ty, Val::FuncRef(None)).unwrap();
     assert_eq!(
         table
@@ -25,7 +25,7 @@ fn fill_wrong() {
         "value does not match table element type"
     );
 
-    let ty = TableType::new(ValType::ExternRef, Limits::new(1, None));
+    let ty = TableType::new(ValType::ExternRef, 1, None);
     let table = Table::new(&mut store, ty, Val::ExternRef(None)).unwrap();
     assert_eq!(
         table
@@ -39,9 +39,9 @@ fn fill_wrong() {
 #[test]
 fn copy_wrong() {
     let mut store = Store::<()>::default();
-    let ty = TableType::new(ValType::FuncRef, Limits::new(1, None));
+    let ty = TableType::new(ValType::FuncRef, 1, None);
     let table1 = Table::new(&mut store, ty, Val::FuncRef(None)).unwrap();
-    let ty = TableType::new(ValType::ExternRef, Limits::new(1, None));
+    let ty = TableType::new(ValType::ExternRef, 1, None);
     let table2 = Table::new(&mut store, ty, Val::ExternRef(None)).unwrap();
     assert_eq!(
         Table::copy(&mut store, &table1, 0, &table2, 0, 1)
